﻿Imports System
Imports System.IO
Imports System.Net
Imports System.Windows
Imports System.Windows.Controls
Imports System.Windows.Data
Imports System.Windows.Media
Imports System.Windows.Media.Animation
Imports System.Windows.Navigation

Imports System.Windows.Documents
Imports Microsoft.Win32
Imports System.Windows.Markup

Partial Public Class Window1
	Public Sub New()
		MyBase.New()

		Me.InitializeComponent()

		' Insert code required on object creation below this point.
	End Sub

    ' Give the selection the chosen font.
    Private Sub cboFont_SelectionChanged(ByVal sender As System.Object, ByVal e As System.Windows.Controls.SelectionChangedEventArgs)
        If (rchNotes Is Nothing) Then Exit Sub
        If e.AddedItems.Count < 1 Then Exit Sub
        Dim item As ComboBoxItem = e.AddedItems.Item(0)
        Dim value As String = item.Content.ToString()

        Dim font_family As New FontFamily(value)
        rchNotes.Selection.ApplyPropertyValue(TextElement.FontFamilyProperty, font_family)
        rchNotes.Focus()
    End Sub

    ' Give the selection the chosen size.
    Private Sub cboSize_SelectionChanged(ByVal sender As System.Object, ByVal e As System.Windows.Controls.SelectionChangedEventArgs)
        If (rchNotes Is Nothing) Then Exit Sub
        If e.AddedItems.Count < 1 Then Exit Sub
        Dim item As ComboBoxItem = e.AddedItems.Item(0)
        Dim value As String = item.Content.ToString()

        rchNotes.Selection.ApplyPropertyValue(TextElement.FontSizeProperty, value)

        rchNotes.Focus()
    End Sub

    ' Give the selection the chosen color.
    Private Sub cboColor_SelectionChanged(ByVal sender As System.Object, ByVal e As System.Windows.Controls.SelectionChangedEventArgs)
        If (rchNotes Is Nothing) Then Exit Sub
        If e.AddedItems.Count < 1 Then Exit Sub
        Dim item As ComboBoxItem = e.AddedItems.Item(0)
        Dim value As String = item.Content.ToString()

        Select Case value
            Case "Black"
                rchNotes.Selection.ApplyPropertyValue(TextElement.ForegroundProperty, Brushes.Black)
            Case "Red"
                rchNotes.Selection.ApplyPropertyValue(TextElement.ForegroundProperty, Brushes.Red)
            Case "Green"
                rchNotes.Selection.ApplyPropertyValue(TextElement.ForegroundProperty, Brushes.Green)
        End Select

        rchNotes.Focus()
    End Sub

    ' Give the selection the chosen weight.
    Private Sub cboWeight_SelectionChanged(ByVal sender As System.Object, ByVal e As System.Windows.Controls.SelectionChangedEventArgs)
        If (rchNotes Is Nothing) Then Exit Sub
        If e.AddedItems.Count < 1 Then Exit Sub
        Dim item As ComboBoxItem = e.AddedItems.Item(0)
        Dim value As String = item.Content.ToString()

        Select Case value
            Case "Normal"
                rchNotes.Selection.ApplyPropertyValue(TextElement.FontWeightProperty, FontWeights.Normal)
            Case "Bold"
                rchNotes.Selection.ApplyPropertyValue(TextElement.FontWeightProperty, FontWeights.Bold)
        End Select

        rchNotes.Focus()
    End Sub

    ' Give the selection the chosen style.
    Private Sub cboStyle_SelectionChanged(ByVal sender As System.Object, ByVal e As System.Windows.Controls.SelectionChangedEventArgs)
        If (rchNotes Is Nothing) Then Exit Sub
        If e.AddedItems.Count < 1 Then Exit Sub
        Dim item As ComboBoxItem = e.AddedItems.Item(0)
        Dim value As String = item.Content.ToString()

        Select Case value
            Case "Normal"
                rchNotes.Selection.ApplyPropertyValue(TextElement.FontStyleProperty, FontStyles.Normal)
            Case "Italic"
                rchNotes.Selection.ApplyPropertyValue(TextElement.FontStyleProperty, FontStyles.Italic)
        End Select

        rchNotes.Focus()
    End Sub

    ' Display the selection's properties.
    Private Sub rchNotes_SelectionChanged(ByVal sender As System.Object, ByVal e As System.Windows.RoutedEventArgs)
        If (rchNotes Is Nothing) Then Exit Sub

        ' Font family.
        Dim font_family As FontFamily = TryCast(rchNotes.Selection.GetPropertyValue(TextElement.FontFamilyProperty), FontFamily)
        If font_family Is Nothing Then
            cboFont.Text = ""
        Else
            cboFont.Text = font_family.Source
        End If

        ' Size.
        cboSize.Text = rchNotes.Selection.GetPropertyValue(TextElement.FontSizeProperty).ToString()

        ' Color.
        Dim br As SolidColorBrush = TryCast(rchNotes.Selection.GetPropertyValue(TextElement.ForegroundProperty), SolidColorBrush)
        If br Is Nothing Then
            cboColor.Text = ""
        Else
            Select Case br.Color.ToString()
                Case Colors.Black.ToString()
                    cboColor.Text = "Black"
                Case Colors.Red.ToString()
                    cboColor.Text = "Red"
                Case Colors.Green.ToString()
                    cboColor.Text = "Green"
                Case Else
                    cboColor.Text = ""
            End Select
        End If

        ' Weight.
        cboWeight.Text = rchNotes.Selection.GetPropertyValue(TextElement.FontWeightProperty).ToString()

        ' Style.
        cboStyle.Text = rchNotes.Selection.GetPropertyValue(TextElement.FontStyleProperty).ToString()
    End Sub

    ' Load a XAML file.
    Private Sub mnuFileOpen_Click(ByVal sender As System.Object, ByVal e As System.Windows.RoutedEventArgs)
        Dim dlg As OpenFileDialog = New Microsoft.Win32.OpenFileDialog()
        dlg.DefaultExt = ".xaml"
        dlg.Filter = "XAML Files (.xaml)|*.xaml|All Files|*.*"

        If (dlg.ShowDialog() = True) Then
            ' Open the file.
            Dim reader As New XamlReader()
            Dim fs As FileStream = File.OpenRead(dlg.FileName)
            Try
                ' Read the FlowDocument stored in the file.
                Dim flow_document As FlowDocument = DirectCast(XamlReader.Load(fs), FlowDocument)

                ' Display the new FlowDocument.
                rchNotes.Document = flow_document
            Catch ex As Exception
                MessageBox.Show(ex.Message, _
                    "Error Reading File", _
                    MessageBoxButton.OK, _
                    MessageBoxImage.Error)
            Finally
                fs.Close()
            End Try
        End If
    End Sub

    ' Save the document.
    Private Sub mnuFileSave_Click(ByVal sender As System.Object, ByVal e As System.Windows.RoutedEventArgs)
        ' Get the file name.
        Dim dlg As New SaveFileDialog()
        dlg.DefaultExt = ".xaml"
        dlg.Filter = "XAML Files (.xaml)|*.xaml|All Files|*.*"

        If (dlg.ShowDialog() = True) Then
            Dim fs As FileStream = File.OpenWrite(dlg.FileName)
            Try
                ' Save.
                XamlWriter.Save(rchNotes.Document, fs)
            Catch ex As Exception
                MessageBox.Show(ex.Message, _
                    "Error Saving File", _
                    MessageBoxButton.OK, _
                    MessageBoxImage.Error)
            Finally
                fs.Close()
            End Try
        End If
    End Sub
End Class
